Crate obrewin_utils

source ·

Structs

  • Iterator struct wrapper for general purposes. This struct is used when you want specific trait to be object safe, but want to return an iterator in that trait’s method.

Traits

  • Similar to Into<BAM<..>>.
  • Convenient trait to convert to Option<T>. IntoOption<T> for F is automatically implemented if TryInto<T> for F is implemented.
  • Convenient trait to wrap iterators.

Type Aliases

  • BAM is an abbreviated name of “BoxedAsyncMethod”. It represents an async method that gets one parameter and returns a boxed async future.